import { resolveVariant } from '../../render/utils/resolve-dynamic-variants.mjs';
import { animateTarget } from './visual-element-target.mjs';
import { animateVariant } from './visual-element-variant.mjs';

function animateVisualElement(visualElement, definition, options = {}) {
    visualElement.notify("AnimationStart", definition);
    let preparedAnimations = [];
    if (Array.isArray(definition)) {
        preparedAnimations = definition.map((variant) => animateVariant(visualElement, variant, options));
    }
    else if (typeof definition === "string") {
        preparedAnimations = [
            animateVariant(visualElement, definition, options),
        ];
    }
    else {
        const resolvedDefinition = typeof definition === "function"
            ? resolveVariant(visualElement, definition, options.custom)
            : definition;
        preparedAnimations = [
            animateTarget(visualElement, resolvedDefinition, options),
        ];
    }
    return () => {
        return Promise.all(preparedAnimations.map((animation) => animation())).then(() => {
            visualElement.notify("AnimationComplete", definition);
        });
    };
}

export { animateVisualElement };
